import requests

class TextlanguageAPIClient:
    def __init__(self, api_key, secure=True):
        """
        Initialize the TextlanguageAPIClient with the API key and secure flag
        :param api_key: API key
        :param secure: Deprecated. Always set to True
        """
        
        self.api_key = api_key
        self.secure = secure
        self.base_url = 'https://api.apiverve.com/v1/textlanguage'
        self.headers = {
            'x-api-key': self.api_key,
            'auth-mode': 'pypi-package'
        }

    def execute(self, params=None):
        """
        Execute the API request
        :param params: API parameters, if any
        :return: API response
        """

        method = "POST"

        try:
            if method.upper() == 'POST':
                response = requests.post(self.base_url, headers=self.headers, json=params)
            else:
                response = requests.get(self.base_url, headers=self.headers, params=params)
            
            response.raise_for_status()
            return response.json()
        except requests.exceptions.RequestException as e:
            print(f"An error occurred: {e}")
            raise e


from setuptools import setup, find_packages

import os
lib_folder = os.path.dirname(os.path.realpath(__file__))
requirements_file = os.path.join(lib_folder, 'requirements.txt')
install_requires = ["requests >= 2.25.1", "setuptools >= 56.0.0"]
if os.path.exists(requirements_file):
    with open(requirements_file, 'r') as f:
        install_requires = f.read().splitlines()

setup(
    name='apiverve_textlanguage',
    version='1.1.5',
    packages=find_packages(),
    include_package_data=True,
    install_requires=install_requires,
    description='Text Language is a simple tool for detecting the language of a text. It returns the language code.',
    author='APIVerve',
    author_email='hello@apiverve.com',
    url='https://apiverve.com',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)